@@ -19,12 +19,10 @@ class EventData(NamedTuple):
     apply_link: str = ''
     title: str = ''
     company: str = ''
+    company_link: str = ''
+    company_img_link: str = ''
     place: str = ''
     description: str = ''
     description_html: str = ''
     date: str = ''
-    seniority_level: str = ''
-    job_function: str = ''
-    employment_type: str = ''
-    industries: str = ''
     insights: List[str] = []
